@@ -1,5 +1,6 @@
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.importlib import import_module
+from django.db import connection
 
 from haystack.utils import get_identifier
 
@@ -19,7 +20,7 @@ def get_update_task(task_path=None):
     except AttributeError:
         raise ImproperlyConfigured('Module "%s" does not define a "%s" '
                                    'class.' % (module, attr))
-    return Task
+    return Task()
 
 
 def enqueue_task(action, instance):
@@ -28,4 +29,15 @@ def enqueue_task(action, instance):
     model instance.
     """
     identifier = get_identifier(instance)
-    get_update_task().delay(action, identifier)
+    kwargs = {}
+    if settings.CELERY_HAYSTACK_QUEUE:
+        kwargs['queue'] = settings.CELERY_HAYSTACK_QUEUE
+    if settings.CELERY_HAYSTACK_COUNTDOWN:
+        kwargs['countdown'] = settings.CELERY_HAYSTACK_COUNTDOWN
+    task = get_update_task()
+    if hasattr(connection, 'on_commit'):
+        connection.on_commit(
+            lambda: task.apply_async((action, identifier), {}, **kwargs)
+        )
+    else:
+        task.apply_async((action, identifier), {}, **kwargs)
